@@ -263,6 +263,7 @@ algorithm_idt <- function(gaze_raw, one_degree = 40, dispersion.threshold =1, mi
 #' @param velocity.threshold Velocity threshold for saccade detection in degrees/second
 #' @param velocity.filter.ms Window in milliseconds for moving average window used for smoothing the sample to sample velocity vector.
 #' @param min.saccade.duration Minimum duration of saccades in milliseconds
+#' @param min.saccade.amplitude Minimum amplitude of saccades in degrees
 #' @param missing.samples.threshold Remove fixations with a higher proportion of missing samples. Range 0 to 1.
 #' @param min.fixation.duration Minimum duration of fixations in milliseconds
 #' @param xcol Name of the column where raw x values are stored. Default: x.raw
@@ -277,13 +278,15 @@ algorithm_idt <- function(gaze_raw, one_degree = 40, dispersion.threshold =1, mi
 #' @param trim.dispersion.threshold If not NA and trim.fixations is TRUE, fixation onsets and offsets will also be shrinked to exclude any samples
 #' at the margins with a larger distance from the centroid than trim.dispersion.threshold*MAD.
 #' @param save.velocity.profiles If TRUE, return velocity profiles of each detected saccade as a variable in the saccades data frame
-#' @return list including separate data frames for fixations and sample-by-sample data including x and y coordinates before and after fixation detection.
+#' @return list including separate data frames for 1) fixations, 2)sample-by-sample data including x and y coordinates before and after fixation detection,
+#' and 3) sample-to-sample velocity
 #' The fixations data frame gives onset, offset, x, y, sample-to-sample RMSD (precision),root-mean-square deviations from fixation centroid,  and missing samples of each fixation.
 #' @examples
 #' ivt_data <- algorithm_ivt(sample.data.processed, velocity.threshold = 30,
 #' min.fixation.duration = 40)
 
-algorithm_ivt <- function(gaze_raw, velocity.filter.ms =20, velocity.threshold = 35, min.saccade.duration = 10, min.fixation.duration = 40,
+
+algorithm_ivt <- function(gaze_raw, velocity.filter.ms =20, velocity.threshold = 35, min.saccade.duration = 10, min.saccade.amplitude = 1, min.fixation.duration = 40,
                         one_degree =40, save.velocity.profiles = FALSE,xcol = "x.raw", ycol = "y.raw", distance.threshold = 0.7,
                         merge.ms.threshold = 75, missing.samples.threshold = 0.5, trim.fixations = FALSE, trim.dispersion.threshold =NA){
 
@@ -404,6 +407,8 @@ algorithm_ivt <- function(gaze_raw, velocity.filter.ms =20, velocity.threshold =
 
   }
   saccades <- dplyr::filter(saccades, .data$duration >= min.saccade.duration)
+  saccades <- dplyr::filter(saccades, .data$amplitude >= min.saccade.amplitude)
+
 
 
   #Loop through all saccades. Define fixations as intervals between saccades.
@@ -440,7 +445,9 @@ algorithm_ivt <- function(gaze_raw, velocity.filter.ms =20, velocity.threshold =
  #Exclude NAs and/or samples with large deciations from the centroid
   if (trim.fixations == TRUE){
 
-    fixations <- trim_fixations(fixations, filt.gaze, xcol = xcol, ycol = ycol,threshold = trim.dispersion.threshold)
+    #fixations <- trim_fixations(fixations, filt.gaze, xcol = xcol, ycol = ycol,threshold = trim.dispersion.threshold)
+    fixations <- trim_fixations(fixations, filt.gaze, xcol = "x.raw", ycol = "y.raw",threshold = trim.dispersion.threshold)
+
   }
 
 
@@ -475,6 +482,7 @@ algorithm_ivt <- function(gaze_raw, velocity.filter.ms =20, velocity.threshold =
   out[["saccades"]] <- saccades
   out[["fixations"]] <-fixations
   out[["filt.gaze"]] <- filt.gaze
+  out[["velocity"]] <- dplyr::select(gaze_raw, .data$timestamp, .data$velocity)
 
   return(out)
 
@@ -506,6 +514,7 @@ algorithm_ivt <- function(gaze_raw, velocity.filter.ms =20, velocity.threshold =
 #' @param velocity.threshold Velocity threshold for saccade detection in degrees/second
 #' @param velocity.filter.ms Window in milliseconds for moving average window used for smoothing the sample to sample velocity vector.
 #' @param min.saccade.duration Minimum duration of saccades in milliseconds
+#' @param min.saccade.amplitude Minimum amplitude of saccades in degrees
 #' @param missing.samples.threshold Remove fixations with a higher proportion of missing samples. Range 0 to 1.
 #' @param min.fixation.duration Minimum duration of fixations in milliseconds
 #' @param xcol Name of the column where raw x values are stored. Default: x.raw
@@ -521,11 +530,11 @@ algorithm_ivt <- function(gaze_raw, velocity.filter.ms =20, velocity.threshold =
 #' @examples
 #' ivt_data <- ivt_filter(sample.data.processed, velocity.threshold = 30, min.fixation.duration = 40)
 
-ivt_filter <- function(gaze_raw, velocity.filter.ms =20, velocity.threshold = 35, min.saccade.duration = 10, min.fixation.duration = 40, one_degree =40, save.velocity.profiles = FALSE,
+ivt_filter <- function(gaze_raw, velocity.filter.ms =20, velocity.threshold = 35, min.saccade.duration = 10, min.saccade.amplitude = 1, min.fixation.duration = 40, one_degree =40, save.velocity.profiles = FALSE,
                           xcol = "x.raw", ycol = "y.raw", distance.threshold = 0.7, merge.ms.threshold = 75, missing.samples.threshold = 0.5, trim.fixations = FALSE, trim.dispersion.threshold =NA){
 
   output <- algorithm_ivt(gaze_raw = gaze_raw, velocity.filter.ms = velocity.filter.ms, velocity.threshold = velocity.threshold,
-                          min.saccade.duration = min.saccade.duration, min.fixation.duration = min.fixation.duration,
+                          min.saccade.duration = min.saccade.duration, min.saccade.amplitude = min.saccade.amplitude, min.fixation.duration = min.fixation.duration,
                           one_degree = one_degree, save.velocity.profiles = save.velocity.profiles,
                           xcol = xcol, ycol = ycol, distance.threshold = distance.threshold, merge.ms.threshold = merge.ms.threshold,
                           missing.samples.threshold = missing.samples.threshold,
@@ -881,6 +890,7 @@ cluster2m <- function (gaze_raw, windowlength.ms = 200, distance.threshold = 0.7
 #' before the propose threshold is identified. Default: 10.
 #' @param min.fixation.duration Minimum duration of accepted fixations. This parameter is also used to calculate 'local noise' prior to the onset of a saccade. Default: 40
 #' @param min.saccade.duration Minimum duration of accepted saccades in ms. Default: 10
+#' @param min.saccade.amplitude Minimum amplitude of accepted saccades in degrees. Default 1
 #' @param save.velocity.profiles If TRUE, save velocity profiles of each saccade. Default: FALSE.
 #' @param missing.samples.threshold Remove fixations with a higher proportion of missing samples. Range 0 to 1.
 #' @param distance.threshold Subsequent fixations occurring withing this distance are merged. Set to 0 if you don't want to merge fixations.
@@ -900,7 +910,7 @@ cluster2m <- function (gaze_raw, windowlength.ms = 200, distance.threshold = 0.7
 
 
 
-algorithm_adaptive <- function(gaze, min.fixation.duration = 40, min.saccade.duration = 10, xcol = "x.raw", ycol = "y.raw",
+algorithm_adaptive <- function(gaze, min.fixation.duration = 40, min.saccade.duration = 10, min.saccade.amplitude = 1, xcol = "x.raw", ycol = "y.raw",
                                save.velocity.profiles = FALSE, missing.samples.threshold = 0.5, merge.ms.threshold = 75,
                                distance.threshold = 0.7, alpha = 0.7, beta = 0.3, one_degree = 40, velocity.filter.ms = 10,
                                peak.threshold.start = 200, onset.threshold.sd = 3, min.period.ms = 40, margin.ms = 3,
@@ -1063,6 +1073,9 @@ algorithm_adaptive <- function(gaze, min.fixation.duration = 40, min.saccade.dur
     }
   }
 
+  saccades <- dplyr::filter(saccades, .data$amplitude >= min.saccade.amplitude)
+
+
   #IDENTIFY FIXATIONS
   message("Searching for fixations")
 
@@ -1087,7 +1100,8 @@ algorithm_adaptive <- function(gaze, min.fixation.duration = 40, min.saccade.dur
   #Merge adjacent fixations
   if (trim.fixations == TRUE){
 
-    fixations <- trim_fixations(fixations, filt.gaze, xcol = xcol, ycol = ycol,threshold = trim.dispersion.threshold)
+    fixations <- trim_fixations(fixations, filt.gaze, xcol = "x.raw", ycol = "y.raw",threshold = trim.dispersion.threshold)
+
   }
 
 
@@ -1282,7 +1296,7 @@ adjust_fixation_timing <- function (fixation.candidate.starts, fixation.candidat
 #' Analogously, fixation offset is shifted backwards to the last included sample with distance to the fixation center under t* MAD + MD
 #'
 #' trim_fixations will look for variables called 'fixation.algorithm' and 'threshold' in the data frame 'fixations'. These columns are produced by kollaR event classification
-#' algorithms. If they are found, they will be transfered to the output data frame.
+#' algorithms. If they are found, they will be transferred to the output data frame.
 #'
 #'
 #' @param fixations Data frame with fixations to trim. The data frame must include the variables 'firstline' (index of first row in the sample-by-sample data belonging to
