@@ -1,3 +1,54 @@
+#'Calculate the moving mean of a vector
+#'@description Calculate the moving mean of a vector while ignoring NAs. Used internally in pre-processing functions
+#'@param x data to process
+#'@param k window length
+#'@return filtered data
+movmean.filter <- function(x, k = 3) {
+
+  x <- zoo::rollapply(
+    x,
+    width = k,
+    FUN = function(y) if(all(is.na(y))) NA_real_ else mean(y, na.rm = TRUE),
+    align = "center",
+    fill = NA,
+    partial = TRUE
+  )
+  return(x)
+}
+
+
+
+#'Calculate sample-to-sample root mean square distance (RMS) of a data segment
+#'@description Calculate the RMS of a gaze segment with X and Y coordinates.
+#'RMS is inversely related to precision, so that lower RMS indicates higher precision
+#'calculate_rms calculates the root mean square of the Euclidean distance between subsequent samples
+#'Adjust the parameters 'xcol' and 'ycol' to specify the data you want to work with. For example, it is possible to calculate
+#'the RMS of the left and right eye separately by specifying appropriate columns.
+#'@param gaze_in data frame with gaze to process. Must contain the variables specified in the parameters 'xcol' and 'ycol'
+#'@param xcol Name of column containing x coordinates
+#'@param ycol Name of column containing y coordinates
+#'@param one_degree One degree of the visual field in the units of the X and Y coordinates as specified in 'xcol' and 'ycol'
+#'@return sample-to-sample RMS
+#'@examples
+#'rms <- calculate_rms(sample.data.unprocessed)
+
+
+calculate_rms <- function(gaze_in, xcol = "x.raw", ycol = "y.raw", one_degree = 40) {
+
+  gaze_in$s2s.x <- c(NA, diff(gaze_in[[xcol]]))
+  gaze_in$s2s.y <- c(NA, diff(gaze_in[[ycol]]))
+  gaze_in$s2s.distance<- sqrt(gaze_in$s2s.x^2 + sqrt(gaze_in$s2s.y^2))
+  gaze_in$s2s.distance.squared<- gaze_in$s2s.distance^2
+
+  rms <- sqrt(mean(gaze_in$s2s.distance.squared, na.rm=T))
+  rms <- rms/one_degree #Normalize to degrees
+  return(rms)
+
+}
+
+
+
+
 
 #'Interpolation and smoothing of gaze-vector
 #'@description Pre-processing gaze
@@ -13,11 +64,12 @@
 #'@param filter_ms The size of the moving average window to use in smoothing. Default 15 ms
 #'@param xcol Name of column containing unprocessed x coordinates
 #'@param ycol Name of column containing unprocessed y coordinates
+#'@param na.ignore If TRUE, ignore NAs when filtering. If FALSE, the zoo function rollmean with the argument na.pad = TRUE will be used.
 #'@return data frame with gaze data after interpolation and filtering
 #'@examples
 #'processed_gaze <- preprocess_gaze(sample.data.unprocessed)
 
-preprocess_gaze <- function(gaze_raw, max_gap_ms = 75, marg_ms = 5, filter_ms = 15, xcol = "x.raw", ycol = "y.raw") {
+preprocess_gaze <- function(gaze_raw, max_gap_ms = 75, marg_ms = 5, filter_ms = 15, xcol = "x.raw", ycol = "y.raw", na.ignore = TRUE) {
   #Recalculate these parameters to number of samples depending on the sampling rate in the gaze vector. Make sure
   #there is a variable called 'timestamp' in the unit ms
 
@@ -26,7 +78,7 @@ preprocess_gaze <- function(gaze_raw, max_gap_ms = 75, marg_ms = 5, filter_ms =
   } else {one.sample <- mean(diff(gaze_raw$timestamp),na.rm=T)}
 
 
-  if (sum(gaze_raw$timestamp<0)>0) {
+  if (sum(gaze_raw$timestamp<0, na.rm =T)>0) {
     warning("The timestamp column contains negative values. Check the data file")
   }
 
@@ -45,8 +97,16 @@ preprocess_gaze <- function(gaze_raw, max_gap_ms = 75, marg_ms = 5, filter_ms =
   gaze_raw[[ycol]]<- interpolate_with_margin(gaze_raw[[ycol]], marg = marg, max_gap = max_gap)
 
   #Smooth the x and y vectors
-  gaze_raw[[xcol]]<- rollmean(gaze_raw[[xcol]], k = filter_window, align = "left", na.pad =T)
-  gaze_raw[[ycol]] <- rollmean(gaze_raw[[ycol]], k = filter_window, align = "left", na.pad =T)
+
+  if (na.ignore == TRUE) {
+     gaze_raw[[xcol]]<- movmean.filter(gaze_raw[[xcol]], k = filter_window)
+     gaze_raw[[ycol]] <- movmean.filter(gaze_raw[[ycol]], k = filter_window)
+  } else {
+    gaze_raw[[xcol]]<- zoo::rollmean(gaze_raw[[xcol]], k = filter_window, align = "left", na.pad =T)
+    gaze_raw[[ycol]] <- zoo::rollmean(gaze_raw[[ycol]], k = filter_window, align = "left", na.pad =T)
+
+  }
+
   gaze_raw$sample <- seq(1, dim(gaze_raw)[1])
   return(gaze_raw)
 
