@@ -553,6 +553,7 @@ animated_fixation_plot <- function(gazedata, xres = 1920, yres = 1080, plot.onse
 #' in the data
 #' @param xcol Name of the column where raw x values are stored. Default: "x.raw"
 #' @param ycol Name of the column where raw y values are stored. Default: "y.raw"
+#' @param font.size Font size
 #' @param verbose If TRUE, print the resulting plot
 #' @return A ggplot showing the sample-to-sample velocity of the selected data interval
 #' @examples
@@ -560,7 +561,7 @@ animated_fixation_plot <- function(gazedata, xres = 1920, yres = 1080, plot.onse
 #'
 
 plot_sample_velocity <- function(data_in, velocity.filter.ms =20, plot.window = c(NA, NA), xcol = "x.raw", ycol = "y.raw", threshold.line = NA,
-                                 one_degree = 40, verbose = TRUE){
+                                 one_degree = 40, font.size = 16, verbose = TRUE){
 
 
 
@@ -613,7 +614,7 @@ plot_sample_velocity <- function(data_in, velocity.filter.ms =20, plot.window =
 
   #Create a ggplot of sample to sample velocity
   data_in$sample <- seq(1, dim(data_in)[1])
-  p <- ggplot(data = data_in, aes(x = .data$sample, y = .data$velocity)) +geom_line(color = "darkblue", linewidth = 1)+theme_minimal()+theme(text = element_text(size =15))+
+  p <- ggplot(data = data_in, aes(x = .data$sample, y = .data$velocity)) +geom_line(color = "darkblue", linewidth = 1)+theme_minimal()+theme(text = element_text(size =font.size))+
     ylab("velocity (degrees/second)")
 
   #Add a line showing a potential threshold for saccade identification
